@@ -27,17 +27,18 @@ public abstract class AbstractDataSourceResolverTest {
 
     protected final int IMG_SIZE = 5866;
 
-    protected byte[] toByteArray(DataSource dataSource) throws IOException
+    protected byte[] toByteArray(final DataSource dataSource) throws IOException
     {
         if(dataSource != null)
         {
             InputStream is = dataSource.getInputStream();
-            return IOUtils.toByteArray(is);
-        }
-        else
-        {
-            return null;
+            try {
+                return IOUtils.toByteArray(is);
+            } finally {
+                is.close();
+            }
         }
+        return null;
     }
 
 }
